@@ -16,11 +16,10 @@ from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 from torchmetrics import Metric as _Metric
 from torchmetrics.collections import MetricCollection as _MetricCollection
 
-from pytorch_lightning.metrics.utils import deprecated_metrics
+from pytorch_lightning.metrics.utils import deprecated_metrics, void
 
 
 class Metric(_Metric):
-
     @deprecated_metrics(target=_Metric)
     def __init__(
         self,
@@ -33,13 +32,14 @@ class Metric(_Metric):
         .. deprecated::
             Use :class:`torchmetrics.Metric`. Will be removed in v1.5.0.
         """
+        void(compute_on_step, dist_sync_on_step, process_group, dist_sync_fn)
 
 
 class MetricCollection(_MetricCollection):
-
     @deprecated_metrics(target=_MetricCollection)
     def __init__(self, metrics: Union[List[Metric], Tuple[Metric], Dict[str, Metric]]):
         """
         .. deprecated::
             Use :class:`torchmetrics.MetricCollection`. Will be removed in v1.5.0.
         """
+        void(metrics)
